@@ -60,8 +60,8 @@ class BaseRecipe(BaseSlapRecipe):
     self._createDirectory(mysql_conf['data_directory'])
 
     mysql_conf_path = self.createConfigurationFile("my.cnf",
-        self.substituteTemplate(pkg_resources.resource_filename(__name__, 'template/my.cnf.in'),
-          mysql_conf))
+        self.substituteTemplate(pkg_resources.resource_filename(__name__,
+        'template/my.cnf.in'), mysql_conf))
 
     mysql_script = pkg_resources.resource_string(__name__,
         'template/mysqlinit.sql.in') % mysql_conf
@@ -153,6 +153,50 @@ class BaseRecipe(BaseSlapRecipe):
     destination = os.path.join(path, file)
     open(destination, 'w').write(open(template, 'r').read() % d)
 
+  def configureInstallation(self, document_root, mysql_conf, url):
+    if not self.options.has_key('delete') and not \
+        self.options.has_key('rename') and not self.options.has_key('script'):
+      return
+    delete = []
+    rename = []
+    rename_list = ""
+    data = {}
+    if self.options.has_key('delete'):
+      for fname in self.options['delete'].split(','):
+        delete.append(os.path.join(document_root, fname.strip()))
+    if self.options.has_key('rename'):
+      for fname in self.options['rename'].split(','):
+        if fname.find("=>") < 0:
+          old_name = fname
+          fname = []
+          fname.append(old_name)
+          fname.append(old_name + '-' + mysql_conf['mysql_user'])
+        else:
+          fname = fname.split("=>")
+        rename.append(dict(old = os.path.join(document_root, fname[0].strip()),
+                           new = os.path.join(document_root, fname[1].strip())
+                           ))
+        rename_list += fname[0] + "=> " + fname[1] + ", "
+    if not self.options.has_key('file_token'):
+      token = dict(
+        table = self.options['table_name'].strip(),
+        constraint=self.options['constraint'].strip()
+      )
+    else:
+      token = os.path.join(document_root, self.options['file_token'].strip())
+    if self.options.has_key('script') and \
+        self.options['script'].strip().endswith(".py"):
+      data = dict(htdocs = document_root,
+                  base_url = url,
+                  script = self.options['script'].strip(),
+                  renamed = rename_list
+                  )
+    self.path_list.extend(zc.buildout.easy_install.scripts(
+        [('configureInstall', __name__ + '.runner', 'executeRunner')], self.ws,
+        sys.executable, self.wrapper_directory, arguments=[delete, rename,
+            token, mysql_conf,data]))
+    return rename_list
+
 class Static(BaseRecipe):
   def _install(self):
     self.path_list = []
@@ -171,8 +215,10 @@ class Simple(BaseRecipe):
     self.createHtdocs(self.options['source'].strip(), document_root)
     mysql_conf = self.installMysqlServer()
     url = self.installApache(document_root)
+    renamed = self.configureInstallation(document_root, mysql_conf, url)
     self.setConnectionDict(dict(
       url=url,
+      rename=renamed,
       **mysql_conf
     ))
     self.createConfiguration(self.options['template'], document_root,
